@@ -1,5 +1,5 @@
 package Dist::Zilla::App::Command::perltidy;
-$Dist::Zilla::App::Command::perltidy::VERSION = '0.08_01';
+our $VERSION = '0.04';
 
 use strict;
 use warnings;
@@ -9,7 +9,7 @@ use Dist::Zilla::App -command;
 
 sub abstract {'perltidy your dist'}
 
-sub execute {
+sub run {
     my ( $self, $opt, $arg ) = @_;
 
     my $perltidyrc;
@@ -50,18 +50,11 @@ sub execute {
 }
 
 1;
-
 __END__
 
-=pod
-
 =head1 NAME
 
-Dist::Zilla::App::Command::perltidy - perltidy your dist
-
-=head1 VERSION
-
-version 0.08_01
+Dist::Zilla::App::Command::perltidy - perltidy a dist
 
 =head1 SYNOPSIS
 
@@ -69,32 +62,29 @@ version 0.08_01
     # OR
     $ dzil perltidy .myperltidyrc
 
-=head2 perltidyrc
+=head1 perltidyrc
 
-=head3 dzil config
+=head2 dzil config
 
-In your global dzil setting (which is '~/.dzil' or '~/.dzil/config.ini'), you can config the
+In your global dzil setting (which is '~/.dzil' or '~/.dzil/config'), you can config the
  perltidyrc like:
 
     [PerlTidy]
     perltidyrc = /home/fayland/somewhere/.perltidyrc
 
-=head3 ENV PERLTIDYRC
+=head2 ENV PERLTIDYRC
 
 If you do not config the dzil, we will fall back to ENV PERLTIDYRC
 
     export PERLTIDYRC=/home/fayland/somwhere2/.perltidyrc
 
-=head1 AUTHORS
+=head1 AUTHOR
 
-  Fayland Lam <fayland@gmail.com>
-  Mark Gardner <mjgardner@cpan.org>
+Fayland Lam, C<< E<lt>fayland@gmail.comE<gt> >>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT
 
-This software is copyright (c) 2010 by Fayland Lam.
+Copyright 2009, Fayland Lam.
 
-This is free software; you can redistribute it and/or modify it under
-the same terms as perl itself.
-
-=cut
+This program is free software; you may redistribute it and/or modify it under
+the same terms as Perl itself.
