@@ -1,22 +1,22 @@
 package Dist::Zilla::Plugin::PerlTidy;
-$Dist::Zilla::Plugin::PerlTidy::VERSION = '0.08_01';
+our $VERSION = '0.04';
 
 # ABSTRACT: PerlTidy in Dist::Zilla
 
 use Moose;
 with 'Dist::Zilla::Role::FileMunger';
 
-has 'perltidyrc' => ( is => 'rw' );
+has 'perltidyrc';
 
 sub munge_file {
     my ( $self, $file ) = @_;
 
-    return $self->_munge_perl($file) if $file->name    =~ /\.(?:pm|pl|t)$/i;
-    return $self->_munge_perl($file) if $file->content =~ /^#!perl(?:$|\s)/;
+    return $self->munge_perl($file) if $file->name    =~ /\.(?:pm|pl|t)$/i;
+    return $self->munge_perl($file) if $file->content =~ /^#!perl(?:$|\s)/;
     return;
 }
 
-sub _munge_perl {
+sub munge_perl {
     my ( $self, $file ) = @_;
 
     my $content = $file->content;
@@ -28,6 +28,16 @@ sub _munge_perl {
         } else {
             warn 'perltidyrc ' . $self->{perltidyrc} . " is not found\n";
         }
+    } elsif ( my $config
+        = $self->zilla->dzil_app->config_for('Dist::Zilla::Plugin::PerlTidy')
+        ) {
+        if ( exists $config->{perltidyrc} ) {
+            if ( -e $config->{perltidyrc} ) {
+                $perltidyrc = $config->{perltidyrc};
+            } else {
+                warn "perltidyrc $config->{perltidyrc} is not found\n";
+            }
+        }
     }
 
     $perltidyrc ||= $ENV{PERLTIDYRC};
@@ -50,19 +60,12 @@ __PACKAGE__->meta->make_immutable;
 no Moose;
 
 1;
-
 __END__
 
-=pod
-
 =head1 NAME
 
 Dist::Zilla::Plugin::PerlTidy - PerlTidy in Dist::Zilla
 
-=head1 VERSION
-
-version 0.08_01
-
 =head1 SYNOPSIS
 
     # dist.ini
@@ -72,38 +75,34 @@ version 0.08_01
     [PerlTidy]
     perltidyrc = xt/.perltidyrc
 
-=head2 perltidyrc
+=head1 perltidyrc
 
-=head3 dist.ini
+=head2 dist.ini
 
     [PerlTidy]
     perltidyrc = xt/.perltidyrc
 
-=head3 ENV PERLTIDYRC
+=head2 dzil config
+
+In your global dzil setting (which is '~/.dzil' or '~/.dzil/config'), you can config the
+ perltidyrc like:
+
+    [PerlTidy]
+    perltidyrc = /home/fayland/somewhere/.perltidyrc
+
+=head2 ENV PERLTIDYRC
 
 If you do not config like above, we will fall back to ENV PERLTIDYRC
 
     export PERLTIDYRC=/home/fayland/somwhere2/.perltidyrc
 
-=head1 METHODS
+=head1 AUTHOR
 
-=head2 munge_file
+Fayland Lam, C<< E<lt>fayland@gmail.comE<gt> >>
 
-Implements the required munge_file method for the
-L<Dist::Zilla::Role::FileMunger> role, munging each Perl file it finds.
-Files whose names do not end in C<.pm>, C<.pl>, or C<.t>, or whose contents
-do not begin with C<#!perl> are left alone.
+=head1 COPYRIGHT
 
-=head1 AUTHORS
+Copyright 2009, Fayland Lam.
 
-  Fayland Lam <fayland@gmail.com>
-  Mark Gardner <mjgardner@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2010 by Fayland Lam.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as perl itself.
-
-=cut
+This program is free software; you may redistribute it and/or modify it under
+the same terms as Perl itself.
